# encoding=utf-8
"""
Auth: coco369
Email: 779598160@qq.com

CreateTime: 2020/07/27

Desc: 解析启动命令行参数, 并创建对应的爬虫
"""
import os
import sys

from commands import create_builder


def _print_command_desc():
	version = ""
	with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "VERSION"), "rb") as f:
		version = f.read().decode().strip()
	print(f"fastspider Version: {version} \n")
	print(f"Usage:")
	print(f"  fastspider <command> [options] [args] \n")

	print(f"Available commands:")
	print(f"  startproject        create project")
	print(f"  startspider         create spider \n")

	print(f'Use "fastspider <command> -h to see more info about a command')


def execute():
	"""
		解析命令行参数
	"""
	argv = sys.argv
	if len(argv) < 4:
		_print_command_desc()
		return

	command = argv.pop(1)
	if command == "startproject":
		# TODO 创建project项目
		pass
	elif command == "startspider":
		create_builder.create()
	else:
		_print_command_desc()






# encoding=utf-8

import os

import setuptools

with open(os.path.join(os.path.join(os.path.dirname(__file__), "fastspider"), "VERSION"), "rb") as f:
	version = f.read().decode().strip()

with open("README.md", 'rb') as f:
	readme = f.read().decode().strip()

all_requires = []
with open(os.path.join(os.path.join(os.path.dirname(__file__), "fastspider"), "requirments.txt"), "rb") as f:
	requires = f.readlines()
	for package in requires:
		if package.decode().strip():
			all_requires.append(package.decode().strip())

packages = setuptools.find_packages()
packages.extend(
	[
		"fastspider",
		"fastspider.templates",
		"fastspider.templates.project",
		"fastspider.templates.spiders",
	]
)

setuptools.setup(
	name="fastspider",
	version=version,
	author="wanghaifei",
	author_email="wanghaifei36@126.com",
	python_requires=">=3.6",
	description="fastspider 爬虫框架",
	long_description=readme,
	entry_points={"console_scripts": ["fastspider=fastspider.start:main"]},
	url="https://github.com/coco369/fastspider.git",
	install_requires=all_requires,
	packages=packages,
	include_package_data=True,
	classifiers=["Programming Language :: Python :: 3"],
)
